@@ -209,11 +209,11 @@ class Tool:
         else:
             return False
 
-    def post_html(self, url, headers={}, data={}, proxy={}, timeout=5, debug=False):
+    def post_html(self, url, headers={}, data={}, json={}, proxy={}, timeout=5, debug=False):
 
         for i in range(5):
             try:
-                res = self.session.post(url, data=data, headers=headers, timeout=timeout, proxies=proxy)
+                res = self.session.post(url, data=data, json=json, headers=headers, timeout=timeout, proxies=proxy)
                 return res
             except Exception as e:
                 if debug:
@@ -697,8 +697,6 @@ class Tool:
                 L.release()
 
 
-
-
 if __name__ == '__main__':
     tool = Tool('local')
     print(len('style="width:220px;word-break: break-all;"'))
